@@ -1,36 +1,48 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 from future.utils import python_2_unicode_compatible
 from bs4 import BeautifulSoup
 
-from .sources import MovieLink, MoviePremierLink, MovieMainPage, MoviePostersPage, MovieTrailersPage, MovieSeries
-from ..utils import KinopoiskObject, Manager, get_request
+from .sources import (
+    MovieLink, MoviePremierLink, MovieMainPage, MoviePostersPage, MovieTrailersPage, MovieSeries, MovieCareerLink)
+from ..utils import KinopoiskObject, Manager, HEADERS
 
 
 @python_2_unicode_compatible
 class Movie(KinopoiskObject):
-
+    """
+    Movie Class
+    """
     def set_defaults(self):
         self.title = ''
-        self.title_original = ''
+        self.title_en = ''
         self.plot = ''
 
         self.year = None
         self.countries = []
         self.tagline = ''
 
+        self.actors = []
         self.directors = []
-        self.scenarios = []
+        self.screenwriters = []
         self.producers = []
         self.operators = []
         self.composers = []
+        self.art_direction_by = []
+        self.editing_by = []
         self.genres = []
 
         self.budget = None
+        self.marketing = None
         self.profit_usa = None
         self.profit_russia = None
+        self.profit_world = None
         self.audience = []
 
         self.rating = None
+        self.votes = None
+        self.imdb_rating = None
+        self.imdb_votes = None
         self.runtime = None
         self.release = None
 
@@ -46,13 +58,14 @@ class Movie(KinopoiskObject):
 
         self.register_source('link', MovieLink)
         self.register_source('premier_link', MoviePremierLink)
+        self.register_source('career_link', MovieCareerLink)
         self.register_source('main_page', MovieMainPage)
         self.register_source('posters', MoviePostersPage)
         self.register_source('trailers', MovieTrailersPage)
         self.register_source('series', MovieSeries)
 
     def __repr__(self):
-        return '%s (%s), %s' % (self.title, self.title_original, self.year or '-')
+        return '{} ({}), {}'.format(self.title, self.title_en, self.year or '-')
 
     def add_trailer(self, trailer_params):
         trailer = Trailer(trailer_params)
@@ -65,7 +78,6 @@ class Movie(KinopoiskObject):
 
 @python_2_unicode_compatible
 class Trailer(object):
-
     def set_defaults(self):
         self.id = None
         self.width = None
@@ -97,16 +109,15 @@ class Trailer(object):
 
     @property
     def is_valid(self):
-        '''
+        """
         Check if filename is correct
-        '''
+        """
         # not youtube video '521689/' (http://www.kinopoisk.ru/film/521689/video/)
         return self.file[-1] != '/'
 
 
 @python_2_unicode_compatible
 class SeriesEpisode(object):
-
     def set_defaults(self):
         self.title = ''
         self.release_date = None
@@ -118,12 +129,11 @@ class SeriesEpisode(object):
         self.release_date = release_date
 
     def __repr__(self):
-        return '%s, %s' % (self.title if self.title else '???', self.release_date or '-')
+        return '{}, {}'.format(self.title if self.title else '???', self.release_date or '-')
 
 
 @python_2_unicode_compatible
 class SeriesSeason(object):
-
     def set_defaults(self):
         self.year = None
         self.episodes = []
@@ -136,13 +146,13 @@ class SeriesSeason(object):
             self.episodes = episodes
 
     def __repr__(self):
-        return '%d: %d' % (self.year, len(self.episodes))
+        return '{}: {}'.format(self.year, len(self.episodes))
 
 
 class MovieManager(Manager):
-    '''
+    """
     Movie manager
-    '''
+    """
     kinopoisk_object = Movie
 
     def get_url_with_params(self, query):
@@ -157,30 +167,29 @@ class MovieManager(Manager):
         })
         # возвращает не по релевантности, а непонятно как
         # http://www.kinopoisk.ru/index.php?level=7&ser=a:3:{s:4:"find";s:3:"day";s:4:"what";s:7:"content";s:5:"count";a:1:{s:7:"content";s:3:"113";}}&show=all
-        return ('http://www.kinopoisk.ru/index.php', {
-            'level': 7,
-            'ser': 'a:3:{s:4:"find";s:%d:"%s";s:4:"what";s:7:"content";s:5:"count";a:1:{s:7:"content";s:3:"113";}}' % (len(query), query),
-            'show': 'all',
-        })
+        # return ('http://www.kinopoisk.ru/index.php', {
+        #     'level': 7,
+        #     'ser': 'a:3:{s:4:"find";s:%d:"%s";s:4:"what";s:7:"content";s:5:"count";a:1:{s:7:"content";s:3:"113";}}' % (
+        #         len(query), query),
+        #     'show': 'all',
+        # })
 
 
 class MoviePremiersManager(Manager):
-
     kinopoisk_object = Movie
 
-    def get_url_with_params(self):
-        return ('http://www.kinopoisk.ru/level/8/view/prem/', {})
+    def get_url_with_params(self, query=None):
+        return 'http://www.kinopoisk.ru/level/8/view/prem/', {}
 
     def all(self):
         url, params = self.get_url_with_params()
-        response = get_request(url, params=params)
+        response = self.request.get(url, params=params, headers=HEADERS)
         content = response.content.decode('windows-1251', 'ignore')
 
-        content_soup = BeautifulSoup(content)
+        content_soup = BeautifulSoup(content, 'html.parser')
         instances = []
         for premier in content_soup.findAll('div', {'class': 'premier_item'}):
-            instance = self.kinopoisk_object()
-            instance.parse('premier_link', premier)
+            instance = self.kinopoisk_object.get_parsed('premier_link', premier)
             instances += [instance]
 
         return instances
